@@ -1,12 +1,9 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/mga/mga_video.c,v 1.33tsi Exp $ */
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "xf86.h"
 #include "xf86_OSproc.h"
-#include "xf86Resources.h"
 #include "compiler.h"
 #include "xf86PciInfo.h"
 #include "xf86Pci.h"
@@ -93,31 +90,28 @@ void MGAInitVideo(ScreenPtr pScreen)
     MGAPtr pMga = MGAPTR(pScrn);
     int num_adaptors;
 
-    if((pScrn->bitsPerPixel != 8) && !pMga->NoAccel &&
-       (pMga->SecondCrtc == FALSE) &&
-       ((pMga->Chipset == PCI_CHIP_MGA2164) ||
-        (pMga->Chipset == PCI_CHIP_MGA2164_AGP) ||     
-/*        (pMga->Chipset == PCI_CHIP_MGA2064) ||     */
-        (pMga->Chipset == PCI_CHIP_MGAG200) ||     
-        (pMga->Chipset == PCI_CHIP_MGAG200_PCI) ||
-        (pMga->Chipset == PCI_CHIP_MGAG400) ||
-	(pMga->Chipset == PCI_CHIP_MGAG550))) 
-    {
-      if( (pMga->Chipset == PCI_CHIP_MGA2164) ||
-/*        (pMga->Chipset == PCI_CHIP_MGA2064) ||   */  
-        (pMga->Chipset == PCI_CHIP_MGA2164_AGP) 
-	) {
-	xf86DrvMsg(pScrn->scrnIndex, X_INFO, "Using MGA 2164W ILOAD video\n");
-	xf86DrvMsg(pScrn->scrnIndex, X_INFO, 
-	"This is an experimental driver and may not work on your machine.\n");
+    if ((pScrn->bitsPerPixel != 8) && !pMga->NoAccel &&
+	(pMga->SecondCrtc == FALSE) &&
+	((pMga->Chipset == PCI_CHIP_MGA2164) ||
+	 (pMga->Chipset == PCI_CHIP_MGA2164_AGP) ||     
+/*	 (pMga->Chipset == PCI_CHIP_MGA2064) ||     */
+	 (pMga->Chipset == PCI_CHIP_MGAG200) ||     
+	 (pMga->Chipset == PCI_CHIP_MGAG200_PCI) ||
+	 (pMga->Chipset == PCI_CHIP_MGAG400) ||
+	 (pMga->Chipset == PCI_CHIP_MGAG550))) {
+	if ((pMga->Chipset == PCI_CHIP_MGA2164) ||
+/*	    (pMga->Chipset == PCI_CHIP_MGA2064) ||   */  
+	    (pMga->Chipset == PCI_CHIP_MGA2164_AGP)) {
+	    xf86DrvMsg(pScrn->scrnIndex, X_INFO, "Using MGA 2164W ILOAD video\n");
+	    xf86DrvMsg(pScrn->scrnIndex, X_INFO, 
+		       "This is an experimental driver and may not work on your machine.\n");
 
-	newAdaptor = MGASetupImageVideoILOAD(pScreen);
-	pMga->TexturedVideo = TRUE; 
-	/* ^^^ this is not really true but the ILOAD scaler shares 
-	much more code with the textured video than the overlay */
-      } else if((pMga->Overlay8Plus24 || pMga->TexturedVideo) &&
-	   (pScrn->bitsPerPixel != 24))
-        {
+	    newAdaptor = MGASetupImageVideoILOAD(pScreen);
+	    pMga->TexturedVideo = TRUE; 
+	    /* ^^^ this is not really true but the ILOAD scaler shares 
+	     * much more code with the textured video than the overlay 
+	     */
+	} else if (pMga->TexturedVideo && (pScrn->bitsPerPixel != 24)) {
 	    xf86DrvMsg(pScrn->scrnIndex, X_INFO, "Using texture video\n");
 	    newAdaptor = MGASetupImageVideoTexture(pScreen);
 	    pMga->TexturedVideo = TRUE;
@@ -126,8 +120,8 @@ void MGAInitVideo(ScreenPtr pScreen)
 	    newAdaptor = MGASetupImageVideoOverlay(pScreen);
 	    pMga->TexturedVideo = FALSE;
 	}
-	if(!pMga->Overlay8Plus24)
-	    MGAInitOffscreenImages(pScreen);
+
+	MGAInitOffscreenImages(pScreen);
     }
 
     num_adaptors = xf86XVListGenericAdaptors(pScrn, &adaptors);
@@ -137,8 +131,8 @@ void MGAInitVideo(ScreenPtr pScreen)
 	    num_adaptors = 1;
 	    adaptors = &newAdaptor;
 	} else {
-	    newAdaptors =  /* need to free this someplace */
-		xalloc((num_adaptors + 1) * sizeof(XF86VideoAdaptorPtr*));
+	    /* need to free this someplace */
+	    newAdaptors = malloc((num_adaptors + 1) * sizeof(XF86VideoAdaptorPtr *));
 	    if(newAdaptors) {
 		memcpy(newAdaptors, adaptors, num_adaptors * 
 					sizeof(XF86VideoAdaptorPtr));
@@ -152,8 +146,7 @@ void MGAInitVideo(ScreenPtr pScreen)
     if(num_adaptors)
         xf86XVScreenInit(pScreen, adaptors, num_adaptors);
 
-    if(newAdaptors)
-	xfree(newAdaptors);
+    free(newAdaptors);
 }
 
 /* client libraries expect an encoding */
@@ -237,10 +230,10 @@ MGAAllocAdaptor(ScrnInfoPtr pScrn, Bool doublebuffer)
     if(!(adapt = xf86XVAllocateVideoAdaptorRec(pScrn)))
 	return NULL;
 
-    if(!(pPriv = xcalloc(1, sizeof(MGAPortPrivRec) + 
+    if(!(pPriv = calloc(1, sizeof(MGAPortPrivRec) +
 			(sizeof(DevUnion) * MGA_MAX_PORTS)))) 
     {
-	xfree(adapt);
+	free(adapt);
 	return NULL;
     }
 
@@ -276,6 +269,8 @@ MGASetupImageVideoOverlay(ScreenPtr pScreen)
     XF86VideoAdaptorPtr adapt;
 
     adapt = MGAAllocAdaptor(pScrn, TRUE);
+    if (adapt == NULL)
+	return NULL;
 
     adapt->type = XvWindowMask | XvInputMask | XvImageMask;
     adapt->flags = VIDEO_OVERLAID_IMAGES | VIDEO_CLIP_TO_VIEWPORT;
@@ -323,6 +318,8 @@ MGASetupImageVideoTexture(ScreenPtr pScreen)
     MGAPtr pMga = MGAPTR(pScrn);
 
     adapt = MGAAllocAdaptor(pScrn, FALSE);
+    if (adapt == NULL)
+	return NULL;
 
     adapt->type = XvWindowMask | XvInputMask | XvImageMask;
     adapt->flags = 0;
@@ -801,11 +798,6 @@ MGADisplayVideoTexture(
    
     CHECK_DMA_QUIESCENT(pMga, pScrn);
 
-    if(pMga->Overlay8Plus24) {
-	WAITFIFO(1);
-	SET_PLANEMASK_REPLICATED( 0x00ffffff, 0xffffffff, 32 );
-    }
-
     WAITFIFO(15);
     OUTREG(MGAREG_TMR0, incx);  /* sx inc */
     OUTREG(MGAREG_TMR1, 0);  /* sy inc */
@@ -1093,18 +1085,18 @@ MGAAllocateSurface(
     surface->width = w;
     surface->height = h;
 
-    if(!(surface->pitches = xalloc(sizeof(int)))) {
+    if(!(surface->pitches = malloc(sizeof(int)))) {
         MGAFreeMemory(pScrn, surface_memory);
 	return BadAlloc;
     }
-    if(!(surface->offsets = xalloc(sizeof(int)))) {
-	xfree(surface->pitches);
+    if(!(surface->offsets = malloc(sizeof(int)))) {
+	free(surface->pitches);
         MGAFreeMemory(pScrn, surface_memory);
 	return BadAlloc;
     }
-    if(!(pPriv = xalloc(sizeof(OffscreenPrivRec)))) {
-	xfree(surface->pitches);
-	xfree(surface->offsets);
+    if(!(pPriv = malloc(sizeof(OffscreenPrivRec)))) {
+	free(surface->pitches);
+	free(surface->offsets);
         MGAFreeMemory(pScrn, surface_memory);
 	return BadAlloc;
     }
@@ -1148,9 +1140,9 @@ MGAFreeSurface(
     if(pPriv->isOn)
 	MGAStopSurface(surface);
     MGAFreeMemory(pScrn, pPriv->surface_memory);
-    xfree(surface->pitches);
-    xfree(surface->offsets);
-    xfree(surface->devPrivate.ptr);
+    free(surface->pitches);
+    free(surface->offsets);
+    free(surface->devPrivate.ptr);
 
     return Success;
 }
@@ -1242,7 +1234,7 @@ MGAInitOffscreenImages(ScreenPtr pScreen)
     XF86OffscreenImagePtr offscreenImages;
 
     /* need to free this someplace */
-    if(!(offscreenImages = xalloc(num * sizeof(XF86OffscreenImageRec))))
+    if(!(offscreenImages = malloc(num * sizeof(XF86OffscreenImageRec))))
 	return;
 
     offscreenImages[0].image = &Images[0];
@@ -1310,6 +1302,8 @@ MGASetupImageVideoILOAD(ScreenPtr pScreen)
     MGAPtr pMga = MGAPTR(pScrn);
 
     adapt = MGAAllocAdaptor(pScrn, FALSE);
+    if (adapt == NULL)
+	return NULL;
 
     adapt->type = XvWindowMask | XvInputMask | XvImageMask;
     adapt->flags = 0;
